@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class LogInfo : public QObject
     Q_OBJECT
 public:
     explicit LogInfo(QObject *parent = nullptr);
-    ~LogInfo();
+    ~LogInfo() override;
 
     void addInfoLogEntry(const QString &log);
     void addErrorLogEntry(const QString &log);
