@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,7 +21,7 @@ public:
     };
 
     explicit PimDataExporterConsole(QObject *parent = nullptr);
-    ~PimDataExporterConsole();
+    ~PimDataExporterConsole() override;
 
     Q_REQUIRED_RESULT Mode mode() const;
     void setMode(Mode mode);
