@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ class ImportMailJobInterfaceTestImpl : public ImportMailJobInterface, public Exp
     Q_OBJECT
 public:
     explicit ImportMailJobInterfaceTestImpl(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
-    ~ImportMailJobInterfaceTestImpl();
+    ~ImportMailJobInterfaceTestImpl() override;
     void start() override;
     void setExistingPathConfig(const QString &path);
 
