@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class ExportNotesJobInterfaceTest : public QObject
     Q_OBJECT
 public:
     explicit ExportNotesJobInterfaceTest(QObject *parent = nullptr);
-    ~ExportNotesJobInterfaceTest() = default;
+    ~ExportNotesJobInterfaceTest() override = default;
 private Q_SLOTS:
     void exportNote_data();
     void exportNote();
