@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class SelectionTypeDialogTest : public QObject
     Q_OBJECT
 public:
     explicit SelectionTypeDialogTest(QObject *parent = nullptr);
-    ~SelectionTypeDialogTest();
+    ~SelectionTypeDialogTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldHideButtons();
