@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ class BackupFileStructureInfoDialog : public QDialog
     Q_OBJECT
 public:
     explicit BackupFileStructureInfoDialog(QWidget *parent = nullptr);
-    ~BackupFileStructureInfoDialog();
+    ~BackupFileStructureInfoDialog() override;
 
 private:
     void readConfig();
