@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class PimDataExporterConfigureWidget : public QWidget
     Q_OBJECT
 public:
     explicit PimDataExporterConfigureWidget(QWidget *parent = nullptr);
-    ~PimDataExporterConfigureWidget();
+    ~PimDataExporterConfigureWidget() override;
 
     void save();
 
